summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/xact.cc3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/xact.cc b/src/xact.cc
index c62974df..5df9ebc5 100644
--- a/src/xact.cc
+++ b/src/xact.cc
@@ -806,8 +806,9 @@ void auto_xact_t::extend_xact(xact_base_t& xact, parse_context_t& context)
xact.add_post(new_post);
new_post->account->add_post(new_post);
// Add flag so this post updates the account balance
new_post->xdata().add_flags(POST_EXT_VISITED);
+ new_post->account->xdata().add_flags(ACCOUNT_EXT_VISITED);
if (new_post->must_balance())
needs_further_verification = true;
@@ -806,8 +806,9 @@ void auto_xact_t::extend_xact(xact_base_t& xact, parse_context_t& context)
xact.add_post(new_post);
new_post->account->add_post(new_post);
- // Add flag so this post updates the account balance
+ // Add flags so this post updates the account balance
new_post->xdata().add_flags(POST_EXT_VISITED);